Module ffi

Module ffi 

Generated bindings for the system libav libraries.

Warning

Documentation for this crate cannot be generated on docs.rs because it requires a system installation of ffmpeg.

Also, the bindings may be different depending on the particular version of ffmpeg installed.

To generate the documentation locally, you can use the cargo rustdoc --open command.